import esp32connection as connection

# Set ssid and password to the SSID and Password of your WiFi
connection.connect("ssid", "password")
